# excel2meta-interface
Convert Excel input for metadata interfaces

## Run
to-do

## Contribute

* Clone this repository
* run the following to get the referenced git repositories
    ```shell
    git submodule init
    git submodule update
    ```